@@ -4,24 +4,20 @@ import (
 	"context"
 	"fmt"
 
-	"github.com/metacubex/mihomo/component/resolver"
 	tlsC "github.com/metacubex/mihomo/component/tls"
 )
 
 type Config struct {
-	EncryptedClientHelloConfigList []byte
+	GetEncryptedClientHelloConfigList func(ctx context.Context, serverName string) ([]byte, error)
 }
 
 func (cfg *Config) ClientHandle(ctx context.Context, tlsConfig *tlsC.Config) (err error) {
 	if cfg == nil {
 		return nil
 	}
-	echConfigList := cfg.EncryptedClientHelloConfigList
-	if len(echConfigList) == 0 {
-		echConfigList, err = resolver.ResolveECH(ctx, tlsConfig.ServerName)
-		if err != nil {
-			return fmt.Errorf("resolve ECH config error: %w", err)
-		}
+	echConfigList, err := cfg.GetEncryptedClientHelloConfigList(ctx, tlsConfig.ServerName)
+	if err != nil {
+		return fmt.Errorf("resolve ECH config error: %w", err)
 	}
 
 	tlsConfig.EncryptedClientHelloConfigList = echConfigList
